export type Nullable<T> = T | null;
export type EyeDropperResult = {
    sRGBHex: string;
};
export type EyeDropper = {
    open: () => Promise<EyeDropperResult>;
};
/**
 * @summary A custom element that implements the EyeDropper API that allows the user to select colors from the screen.
 * @documentation https://github.com/georapbox/eye-dropper-element#readme
 *
 * @tagname eye-dropper - This is the default tag name, unless overridden by the `defineCustomElement` method.
 *
 * @property {boolean} disabled - Whether the element is disabled.
 * @property {boolean} copy - Whether the picked color should be copied to the clipboard.
 *
 * @attribute {boolean} disabled - Reflects the disabled property.
 * @attribute {boolean} copy - Reflects the copy property.
 *
 * @slot button - The slot for the button element.
 * @slot button-label - The slot for the button label.
 *
 * @csspart button - The button element.
 * @csspart button--disabled - The button element when disabled.
 *
 * @event eye-dropper:success - Dispatched when the color is successfully picked.
 * @event eye-dropper:abort - Dispatched when the eye dropper is aborted.
 * @event eye-dropper:error - Dispatched when an error occurs.
 * @event eye-dropper:copy - Dispatched when the picked color is copied to the clipboard.
 *
 * @method defineCustomElement - Static method. Defines the custom element with the given name.
 */
export class EyeDropperElement extends HTMLElement {
    static get observedAttributes(): string[];
    /**
     * Defines a custom element with the given name.
     * The name must contain a dash (-).
     *
     * @param {string} [elementName='eye-dropper'] - The name of the custom element.
     * @example
     *
     * EyeDropperElement.defineCustomElement('my-eye-dropper');
     */
    static defineCustomElement(elementName?: string | undefined): void;
    /**
     * Lifecycle method that is called when attributes are changed, added, removed, or replaced.
     *
     * @param {string} name - The name of the attribute.
     * @param {string} oldValue - The old value of the attribute.
     * @param {string} newValue - The new value of the attribute.
     */
    attributeChangedCallback(name: string, oldValue: string, newValue: string): void;
    set disabled(value: boolean);
    /**
     * @type {boolean} - Whether the element is disabled.
     * @default false
     * @attribute {boolean} disabled - Reflects the disabled property.
     */
    get disabled(): boolean;
    set copy(value: boolean);
    /**
     * @type {boolean} - Whether the picked color should be copied to the clipboard.
     * @default false
     * @attribute {boolean} copy - Reflects the copy property.
     */
    get copy(): boolean;
    /**
     * Lifecycle method that is called when the element is added to the DOM.
     */
    connectedCallback(): void;
    /**
     * Lifecycle method that is called when the element is removed from the DOM.
     */
    disconnectedCallback(): void;
    #private;
}
//# sourceMappingURL=eye-dropper.d.ts.map